@@ -11,10 +11,10 @@ function inputter.appropriate (round, filename, doc)
   elseif round == 2 then
     local sniff = doc:sub(1, 100)
     local promising = sniff:match("^%-%-") or sniff:match("^local") or sniff:match("^return")
-    return promising and inputter.appropriate(3, filename, doc)
+    return promising and inputter.appropriate(3, filename, doc) or false
   elseif round == 3 then
-    local status, _ = pcall(load, doc)
-    return status
+    local status, _ = load(doc)
+    return status and true or false
   end
 end
 
@@ -32,7 +32,6 @@ function inputter:process (doc)
     SILE.process(tree)
   elseif type(tree) == "table" then
     if not tree.type then
-      tree = { tree }
       -- hoping tree is an AST
       self:requireClass(tree)
       return SILE.process(tree)
